%global _enable_debug_package 0
%global debug_package %{nil}

%global ti_version_number 3_15_1_001

Name:		mspds
Version:	3.15.1.1
Release:	3%{?dist}
Summary:	The MSP debug stack (MSPDS) for all MSP430 devices
Group:		Development/Debuggers
License:	BSD-3-Clause
URL:		http://www.ti.com/tool/MSPDS

# Toolchain isn't built for armhfp or s390x, so we exclude it here as well
# https://bugzilla.redhat.com/show_bug.cgi?id=1350884#c59
# https://bugzilla.redhat.com/show_bug.cgi?id=1350884#c64
# README-BUID.txt notes "A 64 bit build is required for use with existing IDEs"
ExcludeArch:	%{arm} %{s390x} %{ix86}

Source0:	https://software-dl.ti.com/msp430/msp430_public_sw/mcu/msp430/MSPDS/%{ti_version_number}/export/MSPDebugStack_OS_Package_3_15_1_1.zip
# Udev rule
Source1:	39-msp430uif.rules

BuildRequires:	gcc-c++
BuildRequires:	boost-devel
BuildRequires:	hidapi-devel
BuildRequires:	pkgconfig(libusb)

%description
The MSP debug stack (MSPDS) for all MSP430 devices is called MSP430.DLL. It
consists of a dynamic link library as well as embedded firmware that runs on
the MSP-FET430UIF or the eZ430 emulators. It is the bridging element between
all PC software and all MSP430 microcontroller derivatives and handles tasks
such as code download, stepping through code, break point handling and so
forth. Examples that use the DLLv3 are IDEs such as Code Composer Studio (CCS),
IAR's Embedded Workbench or others. Also other TI tools like Smart RF Studio or
Elprotronic's FlashPro430 are using the MSP430.DLL.

%prep
%setup -q -c -n %{name}

# Symlink hidapi
ln -s %{_includedir}/hidapi/hidapi.h ThirdParty/include

# Symlink libusb
ln -s %{_libdir}/libhidapi-libusb.so ThirdParty/lib64/hid-libusb.o

# Copy udev rule
cp -a %{SOURCE1} .

%build
# Set build flags
%ifarch %{aarch64}
export CXXFLAGS="%{build_cxxflags} -fPIC"
%endif

make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d
install -D libmsp430.so %{buildroot}%{_libdir}/
install -D 39-msp430uif.rules %{buildroot}%{_sysconfdir}/udev/rules.d/

%files
%{_libdir}/libmsp430.so
/etc/udev/rules.d/39-msp430uif.rules

%changelog
* Fri Sep 15 2023 Brandon Nielsen <nielsenb@jetfuse.net> - 3.15.1.1-3
- Use SPDX for license field

* Sat Feb 4 2023 Brandon Nielsen <nielsenb@jetfuse.net> - 3.15.1.1-2
- Use pkgconfig for libusb

* Thu Aug 12 2021 Brandon Nielsen <nielsenb@jetfuse.net> - 3.15.1.1-1
- Update to 3.15.1.1
- Remove TI-TSPA license, it is no longer mentioned on the webpage, source is BSD
- Add ix86 to ExcludeArch as the documentation specifies 64 bit is required

* Thu Aug 12 2021 Brandon Nielsen <nielsenb@jetfuse.net> - 3.13.0.1-3
- Enable -fPIC for aarch64 only to avoid segfaults on x86_64

* Wed Aug 11 2021 Brandon Nielsen <nielsenb@jetfuse.net> - 3.13.0.1-2
- Add dist tag
- Add ExcludeArch: armhfp s390x as msp43-elf-toolchain excludes them
- Enable -fPIC on everything except ix86

* Wed Mar 27 2019 Brandon Nielsen <nielsenb@jetfuse.net> - 3.13.0.1-1
- Update to 3.13.0.1

* Thu Oct 11 2018 Brandon Nielsen <nielsenb@jetfuse.net> - 3.12.0.4-2
- Add -lboost_thread, -lboost_timer

* Fri Mar 9 2018 Brandon Nielsen <nielsenb@jetfuse.net> - 3.12.0.4-1
- Update to 3.12.0.4
- Update to TI-TSPA license, technically happened with 3.8.0.2

* Sun Oct 29 2017 Brandon Nielsen <nielsenb@jetfuse.net> - 3.10.1.0-1
- Update to 3.10.1.0
- Use passed CXXFLAGS

* Fri May 05 2017 Brandon Nielsen <nielsenb@jetfuse.net> - 3.9.2.15-1
- Promote udev rule to 39 (40 works as well) for programming as user

* Fri Jun 24 2016 Brandon Nielsen <nielsenb@jetfuse.net> - 3.5.1.1-4
- Promote udev rule to 39 (40 works as well) for programming as user

* Fri Jun 24 2016 Brandon Nielsen <nielsenb@jetfuse.net> - 3.5.1.1-3
- Explicitly require gcc-c++ as per Fedora packaging guidelines

* Wed Jun 15 2016 Brandon Nielsen <nielsenb@jetfuse.net> 3.5.1.1-2
- Explicitly include <mutex> for compiling with GCC 6
- Explicitly include <fstream> for compiling with GCC 6

* Tue Oct 27 2015 Brandon Nielsen <nielsenb@jetfuse.net> 3.5.1.1
- Update to 3.5.1.1

* Thu Aug 13 2015 Brandon Nielsen <nielsenb@jetfuse.net> 3.5.1.0
- Update to 3.5.1.0

* Tue Jun 2 2015 Brandon Nielsen <nielsenb@jetfuse.net> 3.5.0.1
- Update to 3.5.0.1

* Sat Jan 31 2015 Brandon Nielsen <nielsenb@jetfuse.net> 3.4.3.4
- Initial version
